"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const getComputedValues_1 = __importDefault(require("./getComputedValues"));
const isAuthenticatedSession_1 = __importDefault(require("./isAuthenticatedSession"));
const cookies_1 = __importDefault(require("./storage/cookies"));
const useInterval_1 = __importDefault(require("./useInterval"));
exports.defaultOptions = {
    isAuthenticated: false,
    jwt: true,
    refreshFn: undefined,
    refreshInterval: 15 * 60 * 1000,
    storage: cookies_1.default
};
const getInitialState = (useSessionOptions) => {
    let options = Object.assign({}, exports.defaultOptions, useSessionOptions);
    options = Object.assign({}, options.storage.get(options.req), options);
    const computedValues = getComputedValues_1.default(options, options);
    options = Object.assign({}, options, computedValues);
    options.storage.set(options, options.expiration);
    return options;
};
const useSession = (options = {}) => {
    if (typeof options !== "object") {
        throw new Error("Invalid option passed to useSession");
    }
    const [state, setState] = react_1.useState(() => getInitialState(options));
    const [errorMessage, setErrorMessage] = react_1.useState(state.errorMessage);
    const setSession = (newState) => {
        const mergedState = getComputedValues_1.default(Object.assign({}, state, newState), state);
        const { accessToken, idToken, refreshToken, storage, token } = mergedState;
        if (mergedState.isAuthenticated) {
            storage.set({ accessToken, idToken, refreshToken, token }, options.expiration);
            setState(mergedState);
        }
        else {
            setState(Object.assign({}, mergedState, { accessToken: undefined, expiration: undefined, idToken: undefined, isAuthenticated: false, refreshToken: undefined, token: undefined }));
        }
    };
    const removeSession = () => {
        window.localStorage.setItem("logout", Date.now().toString());
        setSession({
            accessToken: undefined,
            expiration: undefined,
            idToken: undefined,
            profile: undefined,
            refreshToken: undefined,
            token: undefined
        });
        state.storage.remove();
    };
    const clearErrorMessage = () => setErrorMessage(undefined);
    /**
     * Global logout/login
     */
    react_1.useEffect(() => {
        const logoutEvent = (event) => {
            if (event.key === "logout") {
                removeSession();
            }
            if (state.jwt && event.key === "login") {
                setSession(state.storage.get());
            }
        };
        window.addEventListener("storage", logoutEvent);
        return () => {
            window.localStorage.removeItem("logout");
            window.localStorage.removeItem("login");
            window.removeEventListener("storage", logoutEvent);
        };
    }, []);
    const { expiration, refreshFn, refreshInterval, isAuthenticated } = state;
    /***
     * Remove Session Timer
     */
    const sessionExpiresIn = expiration && isAuthenticated ? expiration.valueOf() - Date.now() : null;
    useInterval_1.default(() => removeSession(), sessionExpiresIn);
    /***
     * RefreshFn timer
     */
    let refreshExpiresIn = null;
    if (refreshFn && refreshInterval) {
        refreshExpiresIn = Math.min(refreshInterval, sessionExpiresIn || Infinity);
    }
    useInterval_1.default(() => {
        setSession(refreshFn(state));
    }, refreshExpiresIn);
    return Object.assign({}, state, { removeSession,
        setSession,
        clearErrorMessage,
        errorMessage,
        setErrorMessage,
        isAuthenticatedGuard() {
            return isAuthenticatedSession_1.default(this);
        } });
};
exports.default = useSession;
//# sourceMappingURL=useSession.js.map